@@ -3,6 +3,7 @@
 #![feature(abi_x86_interrupt)]
 #![feature(alloc_error_handler)]
 #![feature(asm)]
+#![feature(asm_sym)]
 #![feature(naked_functions)]
 #![feature(custom_test_frameworks)]
 #![test_runner(crate::test_runner)]
@@ -18,18 +19,18 @@ pub mod usr;
 
 use bootloader::BootInfo;
 
+const KERNEL_SIZE: usize = 2 << 20; // 2 MB
+
 pub fn init(boot_info: &'static BootInfo) {
     sys::vga::init();
     sys::gdt::init();
     sys::idt::init();
-    unsafe { sys::pic::PICS.lock().initialize() };
-    x86_64::instructions::interrupts::enable();
+    sys::pic::init(); // Enable interrupts
+    sys::serial::init();
+    sys::keyboard::init();
+    sys::time::init();
 
     log!("MOROS v{}\n", env!("CARGO_PKG_VERSION"));
-
-    sys::time::init();
-    sys::keyboard::init();
-    sys::serial::init();
     sys::mem::init(boot_info);
     sys::cpu::init();
     sys::pci::init(); // Require MEM
