@@ -13,11 +13,12 @@ pub fn main(args: &[&str]) -> usr::shell::ExitCode {
         print_hex(&buf);
         usr::shell::ExitCode::CommandSuccessful
     } else {
-        println!("File not found '{}'", pathname);
+        eprintln!("File not found '{}'", pathname);
         usr::shell::ExitCode::CommandError
     }
 }
 
+// TODO: move this to api::hex::print_hex
 pub fn print_hex(buf: &[u8]) {
     let n = buf.len() / 2;
     for i in 0..n {
