@@ -1,14 +1,16 @@
 pub mod base64;
 pub mod beep;
+pub mod calc;
+pub mod chess;
 pub mod clear;
 pub mod colors;
 pub mod copy;
-pub mod chess;
 pub mod date;
 pub mod delete;
 pub mod dhcp;
 pub mod disk;
 pub mod editor;
+pub mod elf;
 pub mod env;
 pub mod find;
 pub mod geotime;
@@ -21,10 +23,11 @@ pub mod httpd;
 pub mod install;
 pub mod ip;
 pub mod keyboard;
-pub mod list;
 pub mod lisp;
+pub mod list;
 pub mod mem;
 pub mod net;
+pub mod pci;
 pub mod print;
 pub mod r#move;
 pub mod read;
